@@ -200,7 +200,6 @@ impl GossipService {
     /// * message - a Message to be packetized and forwarded to the destination
     /// 
     pub fn publish(&mut self, src: &SocketAddr, message: Message) {
-        info!("Received message to publish: {:?}", message);
         let local = self.kad.routing_table.local_info.clone();
         let gossip_to = {
             let mut sample = HashSet::new();
@@ -252,8 +251,6 @@ impl GossipService {
         if let Some(message) = GossipMessage::from_bytes(&msg.msg){
             if !self.cache.contains_key(&MessageKey::from_inner(message.id)) {
                 if *src != self.address {
-                    // TODO: Only print if the protocol id is "chat"
-                    info!("Received message from {:?}", src);
                     if let Err(e) = self.to_app_tx.send(message.clone()) {
                         info!("Error sending message to application layer: {:?}", e)
                     }
@@ -270,7 +267,6 @@ impl GossipService {
         let res = self.to_gossip_rx.try_recv();
         match res {
             Ok((src, msg)) => {
-                info!("Message Received from {:?}:\n{:?}", src, msg);
                 self.handle_message(&src, &msg);
             }
             Err(_) => {}
